@@ -1,7 +1,7 @@
 "sir"<-function(formula1=NULL, formula2=NULL){
 
-   if(class(formula1)!="formula"){stop("formula not passed to formula1 in sir")}
-   if(class(formula2)!="formula"){stop("formula not passed to formula2 in sir")}
+   if(!is(formula1, "formula")){stop("formula not passed to formula1 in sir")}
+   if(!is(formula2, "formula")){stop("formula not passed to formula2 in sir")}
 
    formula1<-update.formula(formula1, ~.-1)
    formula2<-update.formula(formula2, ~.-1)
